# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-sqlite-kernel/compare/first-commit...22f308f2c283513bd6d79f75f9f2de632f980876))

### Maintenance and upkeep improvements

- change repo owner from DerThorsten to jupyterlite [#1](https://github.com/jupyterlite/xeus-sqlite-kernel/pull/1) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-sqlite-kernel/graphs/contributors?from=2022-01-31&to=2022-01-31&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3ADerThorsten+updated%3A2022-01-31..2022-01-31&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3Ajtpio+updated%3A2022-01-31..2022-01-31&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->
